@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2009, 2010, 2016, 2019 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2019 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "color_button.h"
 
@@ -60,14 +47,14 @@ void ColorButton::setColor(const QColor& color)
 	setIconSize(swatch.size());
 	setIcon(swatch);
 
-	emit changed(m_color);
+	Q_EMIT changed(m_color);
 }
 
 //-----------------------------------------------------------------------------
 
 void ColorButton::onClicked()
 {
-	QColor color = QColorDialog::getColor(m_color, this);
+	const QColor color = QColorDialog::getColor(m_color, this);
 	if (color.isValid()) {
 		setColor(color);
 	}
