@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2013, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2013-2014 Graeme Gott <graeme@gottcode.org>
 
-#ifndef DOCX_WRITER_H
-#define DOCX_WRITER_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef FOCUSWRITER_DOCX_WRITER_H
+#define FOCUSWRITER_DOCX_WRITER_H
 
 #include <QCoreApplication>
 #include <QString>
@@ -34,7 +21,7 @@ class DocxWriter
 	Q_DECLARE_TR_FUNCTIONS(DocxWriter)
 
 public:
-	DocxWriter();
+	explicit DocxWriter();
 
 	QString errorString() const
 	{
@@ -59,4 +46,4 @@ private:
 	QString m_error;
 };
 
-#endif
+#endif // FOCUSWRITER_DOCX_WRITER_H
