@@ -334,7 +334,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Images(%1)</source>
+        <source>Images</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1854,4 +1854,11 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
