@@ -29,22 +29,6 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%L1% of %Ln minute(s)</source>
-        <translation>
-            <numerusform>%L1% iš %Ln minutės</numerusform>
-            <numerusform>%L1% iš %Ln minučių</numerusform>
-            <numerusform>%L1% iš %Ln minučių</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%L1% of %Ln word(s)</source>
-        <translation>
-            <numerusform>%L1% iš %Ln žodžio</numerusform>
-            <numerusform>%L1% iš %Ln žodžių</numerusform>
-            <numerusform>%L1% iš %Ln žodžių</numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation>
@@ -65,6 +49,22 @@
         <source>0%</source>
         <translation>0%</translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation>
+            <numerusform>%L1% iš %Ln minutės</numerusform>
+            <numerusform>%L1% iš %Ln minučių</numerusform>
+            <numerusform>%L1% iš %Ln minučių</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation>
+            <numerusform>%L1% iš %Ln žodžio</numerusform>
+            <numerusform>%L1% iš %Ln žodžių</numerusform>
+            <numerusform>%L1% iš %Ln žodžių</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -340,8 +340,8 @@
         <translation>Atverti paveikslą</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Paveikslai(%1)</translation>
+        <source>Images</source>
+        <translation>Paveikslai</translation>
     </message>
 </context>
 <context>
@@ -1860,4 +1860,11 @@
         <translation>Ctrl+Shift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation>Failai, kuriuos atverti dabartiniame seanse.</translation>
+    </message>
+</context>
 </TS>
